@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -13,32 +13,16 @@
 # pylint:disable=missing-module-docstring
 import logging
 from functools import lru_cache
-from importlib.util import find_spec
-from sys import modules
 from typing import (
     Any,
     List,
     Union,
 )
-from warnings import warn
 
 import inflection
 from gql import Client
 from graphql import GraphQLType
-
-# pylint: disable=wrong-import-position
-# Do not use `tqdm.auto` if the user is running Jupyter (IPython is loaded)
-# but ipywidgets is not available (its spec is None or its `has_location` is False).
-# For more info, see: https://github.com/tqdm/tqdm/pull/1218
-ipywidgets_spec = find_spec("ipywidgets")
-if ("IPython" in modules) and (
-    (ipywidgets_spec is None) or (not ipywidgets_spec.has_location)
-):
-    warn("For a better progress bar experience on Jupyter, install `ipywidgets`.")
-    from tqdm.std import tqdm
-else:
-    from tqdm.auto import tqdm
-# pylint: enable=wrong-import-position
+from tqdm.auto import tqdm
 
 from ..queries import (
     MultiRefreshActionQuery,
@@ -90,7 +74,7 @@ class QctrlGraphQLEnvironment(GraphQLEnvironment):
         self._gql_client = gql_client
         super().__init__(type_registry_cls, custom_handlers)
 
-    @lru_cache()
+    @lru_cache(maxsize=128)
     def field_to_attr(self, field_name: str) -> str:
         """Uses inflection to convert a GraphQL
         field name to an attribute name.
