@@ -11,7 +11,6 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 # pylint:disable=missing-module-docstring
-import importlib.util
 import logging
 import re
 import sys
@@ -26,7 +25,6 @@ from typing import (
 )
 
 import commonmark
-import inflection
 import requests
 from gql.transport.exceptions import TransportServerError
 from graphql import (
@@ -227,9 +225,10 @@ def check_client_version(func):
 
 # a namedtuple to define basic information of a package
 # name : the official name of the package
+# pkg_name : installed packaged name
 # url : the URL for hosting the package on PyPI
 # imported when locally available
-_PackageInfo = namedtuple("_PackageInfo", ["name", "url"])
+_PackageInfo = namedtuple("_PackageInfo", ["name", "pkg_name", "url"])
 _QCTRL_URL = "https://pypi.org/pypi/qctrl/json"
 _TOOLKIT_URL = "https://pypi.org/pypi/qctrl-toolkit/json"
 
@@ -239,8 +238,8 @@ class PackageRegistry(Enum):
     Lists Q-CTRL related packages.
     """
 
-    QCTRL = _PackageInfo("Q-CTRL", _QCTRL_URL)
-    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", _TOOLKIT_URL)
+    QCTRL = _PackageInfo("Q-CTRL", "qctrl", _QCTRL_URL)
+    QCTRLTOOLKIT = _PackageInfo("Q-CTRL Toolkit", "qctrltoolkit", _TOOLKIT_URL)
 
     def check_latest_version(self):
         """
@@ -248,7 +247,8 @@ class PackageRegistry(Enum):
         shows upgrade message if the current version is outdated.
         """
         latest_version = _get_latest_version(self.value.url)
-        pkg = self.import_pkg()
+        pkg = sys.modules.get(self.value.pkg_name)
+        assert pkg is not None, f"{self.value.pkg_name} is not found."
         local_version = getattr(pkg, "__version__")
         if version.parse(local_version) < version.parse(latest_version):
             print(
@@ -256,28 +256,6 @@ class PackageRegistry(Enum):
                 f"New version is {latest_version}."
             )
 
-    def is_installed(self) -> bool:
-        """checks whether a package is locally available."""
-        return importlib.util.find_spec(self.get_package_name()) is not None
-
-    def import_pkg(self):
-        """Import the package if it's not already in the sys modules."""
-        pkg_name = self.get_package_name()
-        pkg = sys.modules.get(pkg_name)
-        if pkg is None:
-            spec = importlib.util.find_spec(pkg_name)
-            if spec is None:
-                raise ImportError(f"{self.value.name} not found")
-            module = importlib.util.module_from_spec(spec)
-            spec.loader.exec_module(module)
-            sys.modules[pkg_name] = module
-            return sys.modules[pkg_name]
-        return pkg
-
-    def get_package_name(self) -> str:
-        """Gets the name of the package"""
-        return inflection.parameterize(self.value.name).replace("-", "")
-
 
 def _get_latest_version(url) -> str:
     """
